==> dcb-1.0.8.tgz: dcb-1.0.8/lib/model/QubitRepository.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @package    qubit
 * @subpackage repository
 * @author     Peter Van Garderen <peter@artefactual.com>
 * @version    svn:$Id: QubitRepository.php 3838 2009-10-26 21:01:12Z jablko $
 */
class QubitRepository extends BaseRepository
{

  /**
   * Save new link to a term.
   *
   * @param integer $termId QubitTerm primary key
   * @param string $relationNote DEPRECATED
   */
  public function setTermRelation($termId, $relationNote = null)
  {
    $newTermRelation = new QubitObjectTermRelation;
    $newTermRelation->setTermId($termId);

    //TODO: move to QubitNote
    //  $newTermRelation->setRelationNote($relationNote);
    $newTermRelation->setObjectId($this->getId());
    $newTermRelation->save();
  }

  /**
   * Get many-to-many links to QubitTerm objects
   *
   * @param mixed $taxonomyId  Limit results by taxonomy type
   * @return QubitQuery collection of QubitObjectTermRelation objects
   */
  public function getTermRelations($taxonomyId = 'all')
  {
    $criteria = new Criteria;
    $criteria->add(QubitObjectTermRelation::OBJECT_ID, $this->getId());

    if ($taxonomyId != 'all')
    {
      $criteria->addJoin(QubitObjectTermRelation::TERM_ID, QubitTERM::ID);
      $criteria->add(QubitTerm::TAXONOMY_ID, $taxonomyId);
    }

    return QubitObjectTermRelation::get($criteria);
  }

  /**
   * Create new related QubitNote
   *
   * @param integer $userId     QubitUser id
   * @param string  $note       Note text
   * @param integer $noteTypeId Type of note (QubitTerm pk)
   */
  public function setRepositoryNote($userId, $note, $noteTypeId)
  {
    $newNote = new QubitNote;
    $newNote->setObjectId($this->getId());
    $newNote->setScope('QubitRepository');
    $newNote->setUserId($userId);
    $newNote->setContent($note);
    $newNote->setTypeId($noteTypeId);
    $newNote->save();
  }

  /**
   * Get related notes
   *
   * @return QubitQuery list of QubitNote objects
   */
  public function getRepositoryNotes()
  {
    $criteria = new Criteria;
    $criteria->addJoin(QubitNote::TYPE_ID, QubitTerm::ID);
    $criteria->add(QubitNote::OBJECT_ID, $this->getId());
    $criteria->add(QubitNote::SCOPE, 'QubitRepository');
    QubitNote::addOrderByPreorder($criteria);

    return QubitNote::get($criteria);
  }

  /**
   * Get country of primary contact for repository (If one exists)
   *
   * @return string primary contact's country
   */
  public function getCountry()
  {
    if ($this->getCountryCode())
    {

      return format_country($this->getCountryCode());
    }
  }

  public function getCountryCode()
  {
    if ($this->getPrimaryContact())
    {
      if ($countryCode = $this->getPrimaryContact()->getCountryCode())
      {

        return $countryCode;
      }
    }
    if (count($contacts = $this->getContactInformation()) > 0)
    {
      foreach ($contacts as $contact)
        {
        if ($countryCode = $contact->getCountryCode())
        {

          return $countryCode;
        }
      }
    }
  }

  /**
   * Get information objects in this repository.
   *
   * @return QubitQuery collection of QubitInformationObject objects
   */
  public function getHoldingsPager($options = array())
  {
    $criteria = new Criteria;
    $criteria->add(QubitInformationObject::REPOSITORY_ID, $this->getId());
    $criteria->addAscendingOrderByColumn('title');

    // Sort holdings alphabetically (w/ fallback)
    $criteria = QubitCultureFallback::addFallbackCriteria($criteria, 'QubitInformationObject');

    // Page results
    $page = (isset($options['page'])) ? $options['page'] : 1;
    $pager = new QubitPager('QubitInformationObject');
    $pager->setCriteria($criteria);
    $pager->setPage($page);

    return $pager;
  }

  /**
   * Only find repository objects, not other actor types
   *
   * @param Criteria $criteria current search criteria
   * @return Criteria modified search critieria
   */
  public static function addGetOnlyRepositoryCriteria($criteria)
  {
    $criteria->addJoin(QubitRepository::ID, QubitObject::ID);
    $criteria->add(QubitObject::CLASS_NAME, 'QubitRepository');

    return $criteria;
  }

  public static function addCountryCodeCriteria($criteria, $countryCode)
  {
    if ($countryCode !== null)
    {
      $criteria->addJoin(QubitRepository::ID, QubitContactInformation::ACTOR_ID, Criteria::INNER_JOIN);
      $criteria->add(QubitContactInformation::PRIMARY_CONTACT, true);
      $criteria->add(QubitContactInformation::COUNTRY_CODE, $countryCode);
    }

    return $criteria;
  }

  /**
   * Get a list of repositories.
   *
   * @param string $sort sort order (optional)
   * @param string $countryCode filter by two-letter country code (optional)
   * @return QubitQuery collection of QubitRepository objects
   *
   * @todo implement fallback
   */
  public static function getList($options=array())
  {
    $criteria = new Criteria;

    $cultureFallback = (isset($options['cultureFallback'])) ? $options['cultureFallback'] : false;
    $sort = (isset($options['sort'])) ? $options['sort'] : 'nameUp';
    $page = (isset($options['page'])) ? $options['page'] : 1;

    if (isset($options['countryCode']))
    {
      $criteria = self::addCountryCodeCriteria($criteria, $options['countryCode']);
    }

    //Establish sort order
    switch($sort)
    {
      case 'typeDown' :
        $fallbackTable = 'QubitTerm';
        $criteria->addJoin(QubitRepository::TYPE_ID, QubitTerm::ID, Criteria::INNER_JOIN);
        $criteria->addDescendingOrderByColumn('name');
        break;
      case 'typeUp' :
        $fallbackTable = 'QubitTerm';
        $criteria->addJoin(QubitRepository::TYPE_ID, QubitTerm::ID, Criteria::INNER_JOIN);
        $criteria->addAscendingOrderByColumn('name');
        break;

      /*
       * Can't sort on country "name" currently because it's a lookup value
       * on country *code* (key) with the *name* being returned from
       * symfony's sfCultureInfo data files.
       *
      case 'countryDown' :
        $fallbackTable = 'QubitContactInformation';
        $criteria->addJoin(QubitRepository::ID, QubitContactInformation::ACTOR_ID.' AND '.QubitContactInformation::PRIMARY_CONTACT.'=1', Criteria::LEFT_JOIN);
        $criteria->addDescendingOrderByColumn('country_code');
        break;
      case 'countryUp' :
        $fallbackTable = 'QubitContactInformation';
        $criteria->addJoin(QubitRepository::ID, QubitContactInformation::ACTOR_ID, Criteria::LEFT_JOIN);
        $criteria->addAscendingOrderByColumn('country_code');
        break;
      */
      case 'nameDown' :
        $fallbackTable = 'QubitActor';
        $criteria->addJoin(QubitRepository::ID, QubitActor::ID, Criteria::LEFT_JOIN);
        $criteria->addDescendingOrderByColumn('authorized_form_of_name');
        break;
      case 'nameUp' :
      default :
        $fallbackTable = 'QubitActor';
        $criteria->addJoin(QubitRepository::ID, QubitActor::ID, Criteria::LEFT_JOIN);
        $criteria->addAscendingOrderByColumn('authorized_form_of_name');
    }

    // Do source culture fallback
    if ($cultureFallback === true)
    {
      // Return a QubitQuery object of class-type QubitInformationObject
      $options = array('returnClass'=>'QubitRepository');
      $criteria = QubitCultureFallback::addFallbackCriteria($criteria, $fallbackTable, $options);
    }
    // TODO: add straight joins without fallback

    // Page results
    $pager = new QubitPager('QubitRepository');
    $pager->setCriteria($criteria);
    $pager->setPage($page);
    $pager->init();

    return $pager;
  }

  /**
   * Return an options_for_select array
   *
   * @param mixed $default current selected value for select list
   * @param array $options optional parameters
   * @return array options_for_select compatible array
   */
  public static function getOptionsForSelectList($default, $options = array())
  {
    $repositories = self::getAll($options);

    foreach ($repositories as $repository)
    {
      // Don't display repositories with no name
      if ($name = $repository->getAuthorizedFormOfName($options))
      {
        $selectOptions[$repository->getId()] = $name;
      }
    }

    return options_for_select($selectOptions, $default, $options);
  }

  /**
   * Get related parallel forms of name
   *
   * @return QubitQuery list of parallel names
   */
  public function getParallelFormsOfName()
  {
    $c = new Criteria;
    $c->add(QubitActorName::TYPE_ID, QubitTerm::PARALLEL_FORM_OF_NAME_ID, Criteria::EQUAL);
    $c->addAnd(QubitActorName::ACTOR_ID, $this->getId(), Criteria::EQUAL);

    return QubitActorName::get($c);
  }

  /**
   * Get related other forms of name
   *
   * @return QubitQuery list of other names
   */
  public function getOtherFormsOfName()
  {
    $c = new Criteria;
    $c->add(QubitActorName::TYPE_ID, QubitTerm::OTHER_FORM_OF_NAME_ID, Criteria::EQUAL);
    $c->addAnd(QubitActorName::ACTOR_ID, $this->getId(), Criteria::EQUAL);

    return QubitActorName::get($c);
  }

  /**
   * Add search criteria for find records updated in last $numberOfDays
   *
   * @param Criteria $criteria current search criteria
   * @param string $cutoff earliest date to show
   * @return Criteria modified criteria object
   */
  public static function addRecentUpdatesCriteria($criteria, $cutoff)
  {
    $criteria->add(QubitRepository::UPDATED_AT, $cutoff, Criteria::GREATER_EQUAL);

    return $criteria;
  }

  /**************
  Import methods
  ***************/

  public function setTypeByName($term)
  {
    // see if type term already exists
    $criteria = new Criteria;
    $criteria->addJoin(QubitTerm::ID, QubitTermI18n::ID);
    $criteria->add(QubitTerm::TAXONOMY_ID, QubitTaxonomy::REPOSITORY_TYPE_ID);
    $criteria->add(QubitTermI18n::NAME, $term);
    if ($existingTerm = QubitTerm::getOne($criteria))
    {
      $this->setTypeId($existingTerm->getId());
    }
    else
    {
      $newTerm = new QubitTerm;
      $newTerm->setTaxonomyId(QubitTaxonomy::REPOSITORY_TYPE_ID);
      $newTerm->setName($term);
      $newTerm->save();
      $this->setTypeId($newTerm->getId());
    }
  }
}

==> dcb-1.2.0.tgz: dcb-1.2.0/lib/model/QubitRepository.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @package    qubit
 * @subpackage repository
 * @author     Peter Van Garderen <peter@artefactual.com>
 * @version    svn:$Id: QubitRepository.php 10315 2011-11-14 21:37:12Z david $
 */
class QubitRepository extends BaseRepository
{
  /**
   * Add repository specific logic to the insert action
   *
   * @param mixed $connection The database connection object
   * @return QubitRepository self-reference
   */
  protected function insert($connection = null)
  {
    // When creating a new repository, set the upload_limit to the default
    // value (app_repository_quota)
    if (null == $this->__get('uploadLimit'))
    {
      $this->__set('uploadLimit', sfConfig::get('app_repository_quota'));
    }

    parent::insert($connection);

    return $this;
  }

  /**
   * Create new related QubitNote
   *
   * @param integer $userId     QubitUser id
   * @param string  $note       Note text
   * @param integer $noteTypeId Type of note (QubitTerm pk)
   */
  public function setRepositoryNote($userId, $note, $noteTypeId)
  {
    $newNote = new QubitNote;
    $newNote->setObjectId($this->id);
    $newNote->setScope('QubitRepository');
    $newNote->setUserId($userId);
    $newNote->setContent($note);
    $newNote->setTypeId($noteTypeId);
    $newNote->save();
  }

  /**
   * Get related notes
   *
   * @return QubitQuery list of QubitNote objects
   */
  public function getRepositoryNotes()
  {
    $criteria = new Criteria;
    $criteria->addJoin(QubitNote::TYPE_ID, QubitTerm::ID);
    $criteria->add(QubitNote::OBJECT_ID, $this->id);
    $criteria->add(QubitNote::SCOPE, 'QubitRepository');
    QubitNote::addOrderByPreorder($criteria);

    return QubitNote::get($criteria);
  }

  /**
   * Get country of primary contact for repository (If one exists)
   *
   * @return string primary contact's country
   */
  public function getCountry()
  {
    if ($this->getCountryCode())
    {
      return format_country($this->getCountryCode());
    }
  }

  public function getCountryCode()
  {
    if ($this->getPrimaryContact())
    {
      if ($countryCode = $this->getPrimaryContact()->getCountryCode())
      {
        return $countryCode;
      }
    }
    if (count($contacts = $this->getContactInformation()) > 0)
    {
      foreach ($contacts as $contact)
        {
        if ($countryCode = $contact->getCountryCode())
        {
          return $countryCode;
        }
      }
    }
  }

  /**
   * Only find repository objects, not other actor types
   *
   * @param Criteria $criteria current search criteria
   * @return Criteria modified search critieria
   */
  public static function addGetOnlyRepositoryCriteria($criteria)
  {
    $criteria->addJoin(QubitRepository::ID, QubitObject::ID);
    $criteria->add(QubitObject::CLASS_NAME, 'QubitRepository');

    return $criteria;
  }

  public static function addCountryCodeCriteria($criteria, $countryCode)
  {
    if ($countryCode !== null)
    {
      $criteria->addJoin(QubitRepository::ID, QubitContactInformation::ACTOR_ID);
      $criteria->add(QubitContactInformation::PRIMARY_CONTACT, true);
      $criteria->add(QubitContactInformation::COUNTRY_CODE, $countryCode);
    }

    return $criteria;
  }

  /**
   * Return an options_for_select array
   *
   * @param mixed $default current selected value for select list
   * @param array $options optional parameters
   * @return array options_for_select compatible array
   */
  public static function getOptionsForSelectList($default, $options = array())
  {
    $repositories = self::getAll($options);

    foreach ($repositories as $repository)
    {
      // Don't display repositories with no name
      if ($name = $repository->getAuthorizedFormOfName($options))
      {
        $selectOptions[$repository->id] = $name;
      }
    }

    return options_for_select($selectOptions, $default, $options);
  }

  /**
   * Get disk space used by digital objects in this repository
   *
   * @return integer disk usage in bytes
   */
  public function getDiskUsage($options = array())
  {
    $du = 0;
    $repoDir = sfConfig::get('app_upload_dir').'/r/'.$this->slug;

    if (!file_exists($repoDir))
    {
      return 0;
    }

    // Derived from http://www.php.net/manual/en/function.filesize.php#94566
    $iterator = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($repoDir));
    foreach ($iterator as $item)
    {
      $du += $item->getSize();
    }

    // Set metric units for return value
    if (isset($options['units']))
    {
      switch (strtolower($options['units']))
      {
        case 'g':
          $du /= pow(10, 3);
        case 'm':
          $du /= pow(10, 3);
        case 'k':
          $du /= pow(10, 3);
      }

      $du = round($du, 2);
    }

    return $du;
  }


  /**************
  Import methods
  ***************/

  public function setTypeByName($name)
  {
    // See if type term already exists
    $criteria = new Criteria;
    $criteria->addJoin(QubitTerm::ID, QubitTermI18n::ID);
    $criteria->add(QubitTerm::TAXONOMY_ID, QubitTaxonomy::REPOSITORY_TYPE_ID);
    $criteria->add(QubitTermI18n::NAME, $name);

    if (null === $term = QubitTerm::getOne($criteria))
    {
      $term = new QubitTerm;
      $term->setTaxonomyId(QubitTaxonomy::REPOSITORY_TYPE_ID);
      $term->setName($name);
      $term->setRoot();
      $term->save();
    }

    foreach (self::getTermRelations(QubitTaxonomy::REPOSITORY_TYPE_ID) as $item)
    {
      // Faster than $item->term == $term
      if ($item->termId == $term->id)
      {
        return;
      }
    }

    $relation = new QubitObjectTermRelation;
    $relation->term = $term;

    $this->objectTermRelationsRelatedByobjectId[] = $relation;
  }
}
